@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::Backend::Role::Clear;
+BEGIN {
+  $KiokuDB::Backend::Role::Clear::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Backend::Role::Clear::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: Backend clearing api
 
 use namespace::clean -except => 'meta';
 
@@ -17,6 +22,10 @@ __END__
 
 KiokuDB::Backend::Role::Clear - Backend clearing api
 
+=head1 VERSION
+
+version 0.55
+
 =head1 SYNOPSIS
 
     package KiokuDB::Backend::MySpecialBackend;
@@ -48,3 +57,16 @@ This is optionally used by the dump loader script, and parts of the test suite.
 This method should clear all entries in the backend.
 
 =back
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
