@@ -1,6 +1,10 @@
-#!/usr/bin/perl
-
 package KiokuDB::Backend::Role::Query::GIN;
+BEGIN {
+  $KiokuDB::Backend::Role::Query::GIN::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Backend::Role::Query::GIN::VERSION = '0.55';
+}
 use Moose::Role;
 
 use namespace::clean -except => 'meta';
@@ -41,3 +45,26 @@ sub search_filter {
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Backend::Role::Query::GIN
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
