@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::Backend::Role::Query::Simple::Linear;
+BEGIN {
+  $KiokuDB::Backend::Role::Query::Simple::Linear::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Backend::Role::Query::Simple::Linear::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: Query::Simple implemented with a linear scan of all entries.
 
 use namespace::clean -except => 'meta';
 
@@ -32,8 +37,11 @@ __END__
 
 =head1 NAME
 
-KiokuDB::Backend::Role::Query::Simple::Linear - Query::Simple implemented with
-a linear scan of all entries.
+KiokuDB::Backend::Role::Query::Simple::Linear - Query::Simple implemented with a linear scan of all entries.
+
+=head1 VERSION
+
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -52,3 +60,15 @@ L<KiokuDB::Backend::Role::Query::Simple>) using the api provided by
 L<KiokuDB::Backend::Role::Scan>. While very inefficient for large data sets, of
 your databases are small this can be useful.
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
