@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::Backend::Serialize::Storable;
+BEGIN {
+  $KiokuDB::Backend::Serialize::Storable::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Backend::Serialize::Storable::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: Storable based serialization of KiokuDB::Entry objects.
 
 use Storable qw(nfreeze thaw nstore_fd fd_retrieve);
 
@@ -49,8 +54,11 @@ __END__
 
 =head1 NAME
 
-KiokuDB::Backend::Serialize::Storable - L<Storable> based serialization of
-L<KiokuDB::Entry> objects.
+KiokuDB::Backend::Serialize::Storable - Storable based serialization of KiokuDB::Entry objects.
+
+=head1 VERSION
+
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -86,3 +94,16 @@ Uses L<Storable/nstore_fd>.
 Uses L<Storable/fd_retrieve>.
 
 =back
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
