@@ -1,4 +1,10 @@
 package KiokuDB::Collapser::Buffer;
+BEGIN {
+  $KiokuDB::Collapser::Buffer::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Collapser::Buffer::VERSION = '0.55';
+}
 use Moose;
 
 use Hash::Util::FieldHash::Compat qw(idhash);
@@ -235,3 +241,26 @@ __PACKAGE__->meta->make_immutable;
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Collapser::Buffer
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
