@@ -1,13 +1,18 @@
-#!/usr/bin/perl
-
 package KiokuDB::Entry;
+BEGIN {
+  $KiokuDB::Entry::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Entry::VERSION = '0.55';
+}
 use Moose;
+# ABSTRACT: An entry in the database
 
 use Moose::Util::TypeConstraints;
 
 use namespace::clean -except => 'meta';
 
-with qw(MooseX::Clone);
+with 'MooseX::Clone' => { -version => 0.04 };
 
 has id => (
     isa => "Str",
@@ -313,6 +318,10 @@ __END__
 
 KiokuDB::Entry - An entry in the database
 
+=head1 VERSION
+
+version 0.55
+
 =head1 SYNOPSIS
 
     KiokuDB::Entry->new(
@@ -392,4 +401,15 @@ creates a new derived entry with no data but retaining the ID.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
