@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::GIN;
+BEGIN {
+  $KiokuDB::GIN::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::GIN::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: Gin assisted recollection
 
 use namespace::clean -except => 'meta';
 
@@ -47,6 +52,10 @@ __END__
 
 KiokuDB::GIN - Gin assisted recollection
 
+=head1 VERSION
+
+version 0.55
+
 =head1 SYNOPSIS
 
     use KiokuDB::GIN;
@@ -56,6 +65,15 @@ KiokuDB::GIN - Gin assisted recollection
 This is a generic backend wrapping role that allows adding L<Search::GIN>
 queries to any backend.
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
