@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::Meta::Instance;
+BEGIN {
+  $KiokuDB::Meta::Instance::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Meta::Instance::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: Moose::Meta::Instance level support for lazy loading.
 
 use namespace::clean -except => 'meta';
 
@@ -41,7 +46,11 @@ __END__
 
 =head1 NAME
 
-KiokuDB::Meta::Instance - L<Moose::Meta::Instnace> level support for lazy loading.
+KiokuDB::Meta::Instance - Moose::Meta::Instance level support for lazy loading.
+
+=head1 VERSION
+
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -57,3 +66,15 @@ This allows your L<Moose::Meta::Attributes> to remain oblivious to the fact
 that the value is deferred, making sure that all the type constraints, lazy
 defaults, and various other L<Moose> features continue to work normally.
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
