@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::Reference;
+BEGIN {
+  $KiokuDB::Reference::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Reference::VERSION = '0.55';
+}
 use Moose;
+# ABSTRACT: A symbolic reference to another KiokuDB::Entry.
 
 use namespace::clean -except => 'meta';
 
@@ -46,7 +51,11 @@ __END__
 
 =head1 NAME
 
-KiokuDB::Reference - A symbolic reference to another L<KiokuDB::Entry>.
+KiokuDB::Reference - A symbolic reference to another KiokuDB::Entry.
+
+=head1 VERSION
+
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -75,4 +84,15 @@ This reference is weak.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
