@@ -1,5 +1,12 @@
 package KiokuDB::Role::Upgrade::Data;
+BEGIN {
+  $KiokuDB::Role::Upgrade::Data::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Role::Upgrade::Data::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: Classes that provide their own upgrade routine.
 
 use namespace::clean;
 
@@ -17,6 +24,10 @@ __END__
 
 KiokuDB::Role::Upgrade::Data - Classes that provide their own upgrade routine.
 
+=head1 VERSION
+
+version 0.55
+
 =head1 SYNOPSIS
 
     with qw(KiokuDB::Role::Upgrade::Data);
@@ -41,3 +52,16 @@ approach).
 
 See L<KiokuDB::Role::Upgrade::Handlers::Table> for a more DWIM approach, and
 L<KiokuDB::TypeMap::Entry::MOP> for more details.
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
