@@ -1,6 +1,10 @@
-#!/usr/bin/perl
-
 package KiokuDB::Test::Fixture::Clear;
+BEGIN {
+  $KiokuDB::Test::Fixture::Clear::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Test::Fixture::Clear::VERSION = '0.55';
+}
 use Moose;
 
 use Test::More;
@@ -42,3 +46,25 @@ __PACKAGE__
 
 __END__
 
+=pod
+
+=head1 NAME
+
+KiokuDB::Test::Fixture::Clear
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
