@@ -1,4 +1,10 @@
 package KiokuDB::Test::Fixture::Concurrency;
+BEGIN {
+  $KiokuDB::Test::Fixture::Concurrency::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Test::Fixture::Concurrency::VERSION = '0.55';
+}
 use Moose;
 
 use Test::More;
@@ -232,3 +238,26 @@ __PACKAGE__->meta->make_immutable;
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Test::Fixture::Concurrency
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
