@@ -1,13 +1,17 @@
-#!/usr/bin/perl
-
 package KiokuDB::Test::Fixture::GIN::Class;
+BEGIN {
+  $KiokuDB::Test::Fixture::GIN::Class::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Test::Fixture::GIN::Class::VERSION = '0.55';
+}
 use Moose;
 
 use Test::More;
 use Test::Moose;
 use Scalar::Util qw(refaddr);
 
-use Search::GIN::Query::Class;
+use Search::GIN::Query::Class 0.03;
 
 use namespace::clean -except => 'meta';
 
@@ -70,3 +74,26 @@ __PACKAGE__->meta->make_immutable;
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Test::Fixture::GIN::Class
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
