@@ -1,8 +1,12 @@
-#!/usr/bin/perl
-
 use utf8;
 
 package KiokuDB::Test::Fixture::TypeMap::Default;
+BEGIN {
+  $KiokuDB::Test::Fixture::TypeMap::Default::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Test::Fixture::TypeMap::Default::VERSION = '0.55';
+}
 use Moose;
 
 use Encode;
@@ -31,21 +35,45 @@ use constant HAVE_MX_OP             => try { require MooseX::Object::Pluggable }
 
 {
     package Some::Role;
+BEGIN {
+  $Some::Role::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $Some::Role::VERSION = '0.55';
+}
     use Moose::Role;
 
     has role_attr => ( is => "rw" );
 
     package Some::Other::Role;
+BEGIN {
+  $Some::Other::Role::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $Some::Other::Role::VERSION = '0.55';
+}
     use Moose::Role;
 
     has other_role_attr => ( is => "rw" );
 
     package Some::Third::Role;
+BEGIN {
+  $Some::Third::Role::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $Some::Third::Role::VERSION = '0.55';
+}
     use Moose::Role;
 
     sub a_role_method { "hello" }
 
     package Some::Class;
+BEGIN {
+  $Some::Class::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $Some::Class::VERSION = '0.55';
+}
     use Moose;
 
     if ( KiokuDB::Test::Fixture::TypeMap::Default::HAVE_MX_TRAITS ) {
@@ -133,7 +161,7 @@ sub create {
             },
             op_two => do {
                 my $obj = Some::Class->new( name => "second" );
-                
+
                 $obj->load_plugin("+Some::Other::Role");
 
                 $obj->other_role_attr("after");
@@ -251,7 +279,7 @@ sub verify {
 
         isa_ok( $date, "DateTime" );
     }
-    
+
     if ( HAVE_DATETIME_FMT ) {
         $self->no_live_objects;
         my $s = $self->new_scope;
@@ -259,7 +287,7 @@ sub verify {
         my $date = $self->lookup_ok("datetime_fmt")->{obj};
 
         isa_ok( $date, "DateTime" );
-        
+
         SKIP: {
             skip "Not possible with JSON atm", 1 if (
                 ( $self->directory->backend->can("serializer")
@@ -267,12 +295,12 @@ sub verify {
                 or $self->directory->backend->does("KiokuDB::Backend::Serialize::JSON")
                 or $self->directory->backend->does("KiokuDB::Backend::Serialize::JSPON")
             );
-            
+
             isa_ok( $date->formatter, "DateTime::Format::Strptime" );
         }
-        
+
     }
-    
+
 
     if ( HAVE_URI ) {
         $self->no_live_objects;
@@ -317,7 +345,7 @@ sub verify {
         does_ok( $obj, "Some::Third::Role" );
 
         is( $obj->other_role_attr, "foo", "trait attr" );
-        
+
         is( $obj->name, "blah", "normal attr" );
     }
 
@@ -343,3 +371,26 @@ sub verify {
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Test::Fixture::TypeMap::Default
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
