@@ -1,8 +1,12 @@
-#!/usr/bin/perl
-
 use utf8;
 
 package KiokuDB::Test::Fixture::Unicode;
+BEGIN {
+  $KiokuDB::Test::Fixture::Unicode::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::Test::Fixture::Unicode::VERSION = '0.55';
+}
 use Moose;
 
 use Encode;
@@ -44,3 +48,26 @@ sub verify {
 __PACKAGE__
 
 __END__
+
+=pod
+
+=head1 NAME
+
+KiokuDB::Test::Fixture::Unicode
+
+=head1 VERSION
+
+version 0.55
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
