@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::TypeMap::Default;
+BEGIN {
+  $KiokuDB::TypeMap::Default::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::TypeMap::Default::VERSION = '0.55';
+}
 use Moose::Role;
+# ABSTRACT: A standard KiokuDB::TypeMap with predefined entries.
 
 use namespace::clean -except => 'meta';
 
@@ -82,10 +87,15 @@ __PACKAGE__
 
 __END__
 
+=pod
+
 =head1 NAME
 
-KiokuDB::TypeMap::Default - A standard L<KiokuDB::TypeMap> with predefined
-entries.
+KiokuDB::TypeMap::Default - A standard KiokuDB::TypeMap with predefined entries.
+
+=head1 VERSION
+
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -140,3 +150,16 @@ L<Path::Class::Entity>
 L<Authen::Passphrase>
 
 =back
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
