@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::TypeMap::Entry::MOP;
+BEGIN {
+  $KiokuDB::TypeMap::Entry::MOP::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::TypeMap::Entry::MOP::VERSION = '0.55';
+}
 use Moose;
+# ABSTRACT: A KiokuDB::TypeMap entry for objects with a metaclass.
 
 use Scalar::Util qw(refaddr);
 use Carp qw(croak);
@@ -491,8 +496,11 @@ __END__
 
 =head1 NAME
 
-KiokuDB::TypeMap::Entry::MOP - A L<KiokuDB::TypeMap> entry for objects with a
-metaclass.
+KiokuDB::TypeMap::Entry::MOP - A KiokuDB::TypeMap entry for objects with a metaclass.
+
+=head1 VERSION
+
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -638,3 +646,16 @@ Defaults to false but might default to true in future versions (unless the
 database is in readonly mode).
 
 =back
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
