@@ -1,7 +1,12 @@
-#!/usr/bin/perl
-
 package KiokuDB::TypeMap::Entry::Set;
+BEGIN {
+  $KiokuDB::TypeMap::Entry::Set::AUTHORITY = 'cpan:NUFFIN';
+}
+{
+  $KiokuDB::TypeMap::Entry::Set::VERSION = '0.55';
+}
 use Moose;
+# ABSTRACT: A typemap entry for KiokuDB::Sets
 
 no warnings 'recursion';
 
@@ -137,7 +142,11 @@ __END__
 
 =head1 NAME
 
-KiokuDB::TypeMap::Entry::Set - A typemap entry for L<KiokuDB::Set>s
+KiokuDB::TypeMap::Entry::Set - A typemap entry for KiokuDB::Sets
+
+=head1 VERSION
+
+version 0.55
 
 =head1 DESCRIPTION
 
@@ -146,3 +155,16 @@ various flavours.
 
 You shouldn't need to use it directly, as the default typemap will contain an
 entry for it.
+
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
